@@ -187,8 +187,16 @@ struct hostent *_gethostbyname(const char *name)
 {
     struct hostent *hp;
     char **cp;
-	
 
+    if (name && isdigit(*name)) {
+	host.h_name = name;
+	host.h_aliases = host_aliases;
+	host.h_addrtype = AF_INET;
+	host.h_length = sizeof(u_long);
+	host.h_addr = hostaddr;
+	*((unsigned long *)host.h_addr) = inet_addr(name);
+	return(&host);
+    }
     _sethostent(0);
     while ((hp = _gethostent()) != NULL)
     {
