@@ -343,7 +343,7 @@ struct spwd *_getspnam(const char *name)
 
 static int a_num(char **cp, long val)
 {
-    if (sprintf(*cp, "%ld", val) < 0)
+    if (sprintf(*cp, ":%ld", val) < 0)
 	return -1;
     
     while (**cp)
@@ -364,7 +364,7 @@ int sputspent(const struct spwd *sp, char *buf)
     strcpy(buf, sp->sp_namp);
     strcat(buf, ":");
     strcat(buf, sp->sp_pwdp);
-    strcat(buf, ":");
+/*  strcat(buf, ":"); */
 
     for (cp = buf; *cp; cp++)
 	;
@@ -377,7 +377,7 @@ int sputspent(const struct spwd *sp, char *buf)
 	 a_num(&cp, sp->sp_expire) |
 	 a_num(&cp, (long) sp->sp_flag)))
 	return -1;
-    
+
     return 0;
 }
 
