@@ -103,7 +103,7 @@ static struct netent *netent_parse(char *str, int len)
 
 
 
-void yp_setnetent(int stayopen)
+void _yp_setnetent(int stayopen)
 {
     rewind_flag = 1;
     if (savekey)
@@ -111,7 +111,7 @@ void yp_setnetent(int stayopen)
 }
 
 
-void yp_endnetent(void)
+void _yp_endnetent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -119,7 +119,7 @@ void yp_endnetent(void)
 }
 
 
-struct netent *yp_getnetent(void)
+struct netent *_yp_getnetent(void)
 {
     struct netent *net;
     char *map;
@@ -170,7 +170,7 @@ struct netent *yp_getnetent(void)
 }
 
 
-struct netent *yp_getnetbyaddr(unsigned long net, int type)
+struct netent *_yp_getnetbyaddr(unsigned long net, int type)
 {
     struct netent *nep;
     char *map;
@@ -213,7 +213,7 @@ struct netent *yp_getnetbyaddr(unsigned long net, int type)
 }
 
 
-struct netent *yp_getnetbyname(const char *name)
+struct netent *_yp_getnetbyname(const char *name)
 {
     struct netent *net;
     char *map;
